@@ -185,6 +185,9 @@ INVALIDPARAMETERVALUE_ASYNCTRIGGERCONFIG = 'InvalidParameterValue.AsyncTriggerCo
 # Cdn传入错误。
 INVALIDPARAMETERVALUE_CDN = 'InvalidParameterValue.Cdn'
 
+# cfs配置项重复。
+INVALIDPARAMETERVALUE_CFSPARAMETERDUPLICATE = 'InvalidParameterValue.CfsParameterDuplicate'
+
 # cfs配置项取值与规范不符。
 INVALIDPARAMETERVALUE_CFSPARAMETERERROR = 'InvalidParameterValue.CfsParameterError'
 
@@ -197,6 +200,9 @@ INVALIDPARAMETERVALUE_CKAFKA = 'InvalidParameterValue.Ckafka'
 # Cls传入错误。
 INVALIDPARAMETERVALUE_CLS = 'InvalidParameterValue.Cls'
 
+# 修改Cls配置需要传入Role参数，请修正后重试。
+INVALIDPARAMETERVALUE_CLSROLE = 'InvalidParameterValue.ClsRole'
+
 # Cmq传入错误。
 INVALIDPARAMETERVALUE_CMQ = 'InvalidParameterValue.Cmq'
 
@@ -335,6 +341,9 @@ INVALIDPARAMETERVALUE_PUBLICNETCONFIG = 'InvalidParameterValue.PublicNetConfig'
 # 不支持的函数版本。
 INVALIDPARAMETERVALUE_QUALIFIER = 'InvalidParameterValue.Qualifier'
 
+# RetCode不合法。
+INVALIDPARAMETERVALUE_RETCODE = 'InvalidParameterValue.RetCode'
+
 # RoutingConfig取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
 INVALIDPARAMETERVALUE_ROUTINGCONFIG = 'InvalidParameterValue.RoutingConfig'
 
@@ -503,6 +512,9 @@ RESOURCENOTFOUND_ASYNCEVENT = 'ResourceNotFound.AsyncEvent'
 # Cdn不存在。
 RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 
+# 指定的cfs下未找到您所指定的挂载点。
+RESOURCENOTFOUND_CFSMOUNTINSNOTMATCH = 'ResourceNotFound.CfsMountInsNotMatch'
+
 # cfs与云函数所处vpc不一致。
 RESOURCENOTFOUND_CFSVPCNOTMATCH = 'ResourceNotFound.CfsVpcNotMatch'
 
